#
# spec file for package ghc-crypton
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name crypton
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.4
Release:        1.2
Summary:        Cryptography Primitives sink
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-basement-devel
BuildRequires:  ghc-basement-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-memory-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-kat-devel
BuildRequires:  ghc-tasty-kat-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
A repository of cryptographic primitives.

* Symmetric ciphers: AES, DES, 3DES, CAST5, Blowfish, Twofish, Camellia, RC4,
Salsa, XSalsa, ChaCha.

* Hash: SHA1, SHA2, SHA3, SHAKE, MD2, MD4, MD5, Keccak, Skein, Ripemd, Tiger,
Whirlpool, Blake2

* MAC: HMAC, KMAC, Poly1305

* Asymmetric crypto: DSA, RSA, DH, ECDH, ECDSA, ECC, Curve25519, Curve448,
Ed25519, Ed448

* Key Derivation Function: PBKDF2, Scrypt, HKDF, Argon2, BCrypt, BCryptPBKDF

* Cryptographic Random generation: System Entropy, Deterministic Random
Generator

* Data related: Anti-Forensic Information Splitter (AFIS)

If anything cryptographic related is missing from here, submit a pull request
to have it added. This package strives to be a cryptographic kitchen sink that
provides cryptography for everyone.

Evaluate the security related to your requirements before using.

Read "Crypto.Tutorial" for a quick start guide.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Mar 30 2025 Peter Simons <psimons@suse.com>
- Update crypton to version 1.0.4.
  [#]# 1.0.4
  * Ed448.sign: avoid extra re-derive of public key.
    [#48](https://github.com/kazu-yamamoto/crypton/pull/48)
* Sat Mar 29 2025 Peter Simons <psimons@suse.com>
- Update crypton to version 1.0.3.
  [#]# 1.0.3
  * Make sign of Ed25519/Ed448 safer. The public key parameter is
    ignored and its public key is generated from the secret key
    parameter to prevent Double Public Key Signing Function Oracle
    Attack.
    [#47](https://github.com/kazu-yamamoto/crypton/pull/47)
* Tue Mar 11 2025 Peter Simons <psimons@suse.com>
- Update crypton to version 1.0.2.
  [#]# 1.0.2
  * Deterministic Nonce Generation for ECDSA
    [#46](https://github.com/kazu-yamamoto/crypton/pull/46)
  * ECDSA Signature Normalization.
    [#45](https://github.com/kazu-yamamoto/crypton/pull/45)
  * Add Full Test Suite from RFC 6979.
    [#44](https://github.com/kazu-yamamoto/crypton/pull/44)
  * ECDSA with Public Key Recovery.
    [#43](https://github.com/kazu-yamamoto/crypton/pull/43)
  * Providing necessary features for HPKE.
    [#42](https://github.com/kazu-yamamoto/crypton/pull/42)
* Fri Oct 18 2024 Peter Simons <psimons@suse.com>
- Update crypton to version 1.0.1.
  [#]# 1.0.1
  * Update decaf library.
    [#38](https://github.com/kazu-yamamoto/crypton/pull/38)
  * Add TypeOperators language extension to EdDSA.hs.
    [#36](https://github.com/kazu-yamamoto/crypton/pull/36)
* Thu Apr 25 2024 Peter Simons <psimons@suse.com>
- Update crypton to version 1.0.0.
  [#]# 1.0.0
  * Versions follow the standard version policy.
  * Removing pthread stuff.
    [#32](https://github.com/kazu-yamamoto/crypton/pull/32)
* Fri Nov 10 2023 Peter Simons <psimons@suse.com>
- Update crypton to version 0.34.
  [#]# 0.34
  * Hashing getRandomBytes before using as Seed for ChaChaDRG
    [#24](https://github.com/kazu-yamamoto/crypton/pull/24)
  * Add support for XChaCha and XChaChaPoly1305
    [#18](https://github.com/kazu-yamamoto/crypton/pull/18)
  * Strict byteArray of IV c
    [#16](https://github.com/kazu-yamamoto/crypton/pull/16)
* Wed Jul  5 2023 Peter Simons <psimons@suse.com>
- Add crypton at version 0.33.
